module.exports = function (grunt) {

	var srcFiles = {
		js: ["src/assets/js/controllers/**/*.js"]
	};

	grunt.initConfig({
		jshint: {
			all: srcFiles.js.concat(["GruntFile.js"])
		},
		watch: {
			js: {
				files: srcFiles.js,
				tasks: ['jshint', 'concat:js']
			}
		},
		concat: {
			js: {
				options: {
					process: function (src, filepath) {
						return '// FILE: ' + filepath + '\n' + src + '\n';
					}
				},
				src: srcFiles.js,
				dest: 'dist/rui.js'
			}
		},
		uglify: {
			options: {
				mangle: false,
				compress: false,
				report: 'min',
				// the banner is inserted at the top of the output
				banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
			},
			dist: {
				files: {
					'dist/rui.min.js': srcFiles.js
				}
			}
		},
		bump: {
			options: {
				files: ['bower.json', 'package.json'],
				pushTo: 'origin',
				commitFiles: ["-a"],
				push: true
			}
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-bump');

	// Default task.
	grunt.registerTask('default', ['jshint', 'concat', 'uglify']);

};